@@ -1,6 +1,7 @@
-"""A GenerateCommand Command."""
 from cleo import Command
-from masonite.js_routes.generator import RoutesGenerator
+from masonite.utils.filesystem import make_directory
+
+from ..generator import RoutesGenerator
 
 
 class GenerateCommand(Command):
@@ -16,9 +17,10 @@ class GenerateCommand(Command):
             default_path = self.option("path")
         else:
             default_path = "resources/js/routes.js"
-        self.info("Start generation of JS Routes ...")
+        self.info("Start generating JS Routes...")
         generator = RoutesGenerator()
         file_content = generator.generate_for_file()
+        make_directory(default_path)
         with open(default_path, "w") as f:
             f.write(file_content)
-        self.info("JS Routes generated in {0}!".format(default_path))
+        self.info("routes file has been generated at {0}!".format(default_path))
